/*
 *+------------------------------------------------------------------------+
 *| Licensed Materials - Property of IBM                                   |
 *| (C) Copyright IBM Corp. 2012.  All Rights Reserved.              |
 *|                                                                        |
 *| US Government Users Restricted Rights - Use, duplication or disclosure |
 *| restricted by GSA ADP Schedule Contract with IBM Corp.                 |
 *+------------------------------------------------------------------------+
 */
command {

	name "save"
	description "Save the response file script."
		contexts "create", "edit"
		
		instance {
		    invoke {
				def list = com.ibm.edp.rfe.model.ScriptList.getInstance()
 		        def script = list.getCurrentScript();
				def filename = arguments["filename"]
				def swoverwrite = switches["-overwrite"]
				def overwrite = ""
				if ( swoverwrite ) {
					overwrite = swoverwrite["-overwrite"]
				}
				
				if ( !filename || filename.size() == 0 ){
					filename = script.getName()
				}
				
				if ( filename == "untitled.response" ) {
					def newfilename = session.getInput().readDirect( session, "Enter a response file name: " )
					if( newfilename.trim().length() > 0 ) filename = newfilename						       		
				}
				
				if ( !filename.endsWith(".response") ) {
					filename = filename + ".response"
				}
				
				def file = new File(filename)				
				script.name = filename
				
				if ( !file.exists() ) {
					if( com.ibm.edp.rfe.model.ModelUtil.saveScript(script, file) ){
					   script.saved()
					   sprintln "Save complete"
					}//if
				}
				else {
					if ( overwrite.size() == 0 ) {
						def defaultvalue = "Yes"
						def tmp = session.getInput().readDirect( session, "Overwrite $filename? (Yes/No) [" + defaultvalue + "]: " )
						if (tmp.trim().length() > 0) {
							if (tmp.compareToIgnoreCase("Yes") != 0) {
								overwrite = "No"
							}
							else {
								overwrite = "Yes"
							}
						}
						else {
							overwrite = defaultvalue
						}
					}
					if ( overwrite.compareToIgnoreCase("Yes") == 0 ) {
										
						if( com.ibm.edp.rfe.model.ModelUtil.saveScript(script, file) ){
						   script.saved()
						   sprintln "Save complete"
						}//if
						
					} 					
				}
		    }	
		}
		arguments {	     
			"filename" {
		    	datatype "filename"
	    		optional true
	        	description "File name for saving the current response file."	        	        
		    }
			"-overwrite" {
				datatype "switch"
				optional true
				description "Specifies whether you wish to overwrite a given file's contents."
				
					"-overwrite" {
						description "Yes/No"
						datatype "list"
						values { 
							["Yes", "No"]
						}
					}
					
				values "Yes", "No"
			}				     
		}
}