/*
 *+------------------------------------------------------------------------+
 *| Licensed Materials - Property of IBM                                   |
 *| (C) Copyright IBM Corp. 2012.  All Rights Reserved.              |
 *|                                                                        |
 *| US Government Users Restricted Rights - Use, duplication or disclosure |
 *| restricted by GSA ADP Schedule Contract with IBM Corp.                 |
 *+------------------------------------------------------------------------+
 */
query_script_version '1.0.0'

packageid 'com.ibm.buildforge.console'
packageversion '[7.1.0,8.1.0)'

query_order {
	custom {
		install {
			licenseType
			licenseServer
			licensePort
			licenseFile
			dbType
			populateDb
			dbHost
			dbPort
			dbName
			dbSchema
			odbcDatasource
			dbUser
			dbPassword
			dbConfirmPass
			db2ClientLibs
			oracleClientLibs
			oracleHomePath
			oracleTsnamesPath
			mysqlLibLocation
			jdbcLocation
			supplyOwnWebserver
			webserverPort
			useHttps
			memoryLimitPhp
			webserverDomainName
			supplyOwnAppserver
			httpPort
			sslPort
			ajpPort
			shutdownPort
			redirectionUrl
			pluginsDirectory
			servicesDomainName
			listenOnPort
			listenOnSecureport
			keystorePassword
			confirmKeystorePass
			uploadCustomCert
			existingSignedCert
			validityPeriodType
			validityPeriod
			commonName
			locality
			state
			orgName
			orgUnit
			countryName
			streetAddress
			signedCertLocation
			createShortcut
			startupOptions
			beta
			installType
			win2k8
			bfPlatform
			javaHome
			runAs
			fileStorage
			uninstallFull
			realHost
		}
		update {
			
		}
		uninstall {
			
		}
	}
}

query {
	id "licenseType"
	required true
	dependencies advancedType
	label "What type of license will this console use"
	labelType "text"
	inputType "list"
	inputDefault "Rational License Server Based"
	inputOptions "Rational License Server Based, File Based"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		
	}
}

query {
	id "licenseServer"
	required true
	dependencies advancedType
	label "License server"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes") && licenseType.equalsIgnoreCase("Rational License Server Based")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.licenseServer", licenseServer)
	}
}

query {
	id "licensePort"
	required true
	dependencies advancedType
	label "License port"
	labelType "text"
	inputType "text"
	inputDefault "27000"
	condition {
		advancedType.equalsIgnoreCase("Yes") && licenseType.equalsIgnoreCase("Rational License Server Based")
	}
	validation {
		if (!licensePort.isInteger()) {
			println "The value must be an integer"
			return false
		}
		if ((licensePort.toInteger() < 1) || (licensePort.toInteger() > 65535)) {
			println "The port number must be between 1 and 65536"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.licensePort", licensePort)
	}
}

query {
	id "licenseFile"
	required true
	dependencies advancedType
	label "Specify the license file"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes") && licenseType.equalsIgnoreCase("File Based")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.licenseFile", licenseFile)
	}
}


query {
	id "dbType"
	required true
	dependencies platform
	label "Database type"
	labelType "text"
	inputType "list"
	inputDefault "DB2"
	inputOptions "DB2,Oracle 10,Oracle 11,MySQL Server 5,SQL Server 2005,SQL Server 2008"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (dbType.equalsIgnoreCase("MySQL Server 5")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbComboType", "mysql50")
		}
		else if (dbType.equalsIgnoreCase("DB2")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbComboType", "db2")
		}
		else if (dbType.equalsIgnoreCase("Oracle 10")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbComboType", "oracle10")
		}
		else if (dbType.equalsIgnoreCase("Oracle 11")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbComboType", "oracle11")
		}
		else if (dbType.equalsIgnoreCase("SQL Server 2005")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbComboType", "sqlserver2005")
		}
		else if (dbType.equalsIgnoreCase("SQL Server 2008")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbComboType", "sqlserver2008")
		}
	}
}

query {
	id "populateDb"
	required true
	dependencies platform
	label "Do you wish to populate this database at install time"
	labelType "text"
	inputType "list"
	inputOptions "Yes, No"
	inputDefault "Yes"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (populateDb.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.schema.question", "y")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.schema.question", "n")
		}	
	}
}

query {
	id "dbHost"
	required true
	dependencies platform
	label "Database Host"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbHost", dbHost)
	}
}

query {
	id "dbPort"
	required true
	dependencies platform
	label "Database Port"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		if (!dbPort.isInteger()) {
			println "The value must be an integer"
			return false
		}
		if ((dbPort.toInteger() < 1) || (dbPort.toInteger() > 65535)) {
			println "The port number must be between 1 and 65536"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbPort", dbPort)
	}
}

query {
	id "dbName"
	required true
	dependencies platform
	label "Database Name"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbName", dbName)
	}
}

query {
	id "dbSchema"
	required true
	dependencies platform
	label "Database Schema Name"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes") && dbType.equalsIgnoreCase("DB2")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbSchema", dbSchema)
	}
}

query {
	id "odbcDatasource"
	required true
	dependencies platform
	label "ODBC Data Source Name"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes") && (dbType.equalsIgnoreCase("SQL Server 2005") || dbType.equalsIgnoreCase("SQL Server 2008")) 
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbODBC", odbcDatasource)
	}
}

query {
	id "dbUser"
	required true
	dependencies platform
	label "Database Username"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbUser", dbUser)
	}
}

query {
	id "dbPassword"
	required true
	dependencies platform
	label "Password"
	labelType "text"
	inputType "password"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		// This value is only set if it is properly confirmed
		// com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbPass", dbPassword)
	}
}

query {
	id "dbConfirmPass"
	required true
	dependencies platform
	label "Confirm password"
	labelType "text"
	inputType "password"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		if (!dbConfirmPass.equals(dbPassword)) {
			println "Passwords do not match"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbPass", dbConfirmPass)
	}
}

query {
	id "db2ClientLibs"
	required true
	dependencies platform
	label {
		"Path to the DB2 client libraries (${platform?platform+' ':''})"
	}
	labelType "text"
	inputType "text", "file"
	condition {
		advancedType.equalsIgnoreCase("Yes") && dbType.equalsIgnoreCase("DB2")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setPlatformProperty(pkg, env, platform, "user.buildforge.db2Home", db2ClientLibs)
		db2ClientLibs = null
	}
}

query {
	id "oracleClientLibs"
	required true
	dependencies platform
	label { 
		"Path to the Oracle client libraries (${platform?platform+' ':''})"
	}
	labelType "text"
	inputType "text", "file"
	condition {
		advancedType.equalsIgnoreCase("Yes") && (dbType.equalsIgnoreCase("Oracle 10") || dbType.equalsIgnoreCase("Oracle 11")) 
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setPlatformProperty(pkg, env, platform, "user.buildforge.driverLib", oracleClientLibs)
		oracleClientLibs = null
	}
}

query {
	id "oracleHomePath"
	required true
	dependencies platform
	label { 
		"The ORACLE_HOME environment variable path (${platform?platform+' ':''})"
	}
	labelType "text"
	inputType "text", "file"
	condition {
		advancedType.equalsIgnoreCase("Yes") && (dbType.equalsIgnoreCase("Oracle 10") || dbType.equalsIgnoreCase("Oracle 11")) 
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setPlatformProperty(pkg, env, platform, "user.buildforge.oracleHome", oracleHomePath)
		oracleHomePath = null
	}
}

query {
	id "oracleTsnamesPath"
	required true
	dependencies platform
	label {
		"Path to tnsnames.ora file (TNS_ADMIN) (${platform?platform+' ':''})"
	}
	labelType "text"
	inputType "text", "file"
	condition {
		advancedType.equalsIgnoreCase("Yes") && (dbType.equalsIgnoreCase("Oracle 10") || dbType.equalsIgnoreCase("Oracle 11")) 
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setPlatformProperty(pkg, env, platform, "user.buildforge.oracleTNS", oracleTsnamesPath)
		oracleTsnamesPath = null
	}
}

query {
	id "mysqlLibLocation"
	required true
	dependencies platform
	label {
		"Path to the MySQL client libraries (${platform?platform+' ':''})"
	}
	labelType "text"
	inputType "text", "file"
	condition {
		advancedType.equalsIgnoreCase("Yes") && dbType.equalsIgnoreCase("MySQL Server 5")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setPlatformProperty(pkg, env, platform, "user.buildforge.driverLib", mysqlLibLocation)
		mysqlLibLocation = null
	}
}

query {
	id "jdbcLocation"
	required true
	dependencies platform
	label {
		"JDBC driver location (${platform?platform+' ':''})"
	}
	labelType "text"
	inputType "text", "file"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setPlatformProperty(pkg, env, platform, "user.buildforge.jdbcDriverDir", jdbcLocation)
		jdbcLocation = null
	}
}

query {
	id "supplyOwnWebserver"
	required true
	dependencies advancedType
	label "Supply your own web server"
	labelType "text"
	inputType "list"
	inputOptions "Yes, No"
	inputDefault "No"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (supplyOwnWebserver.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.apache.install", "y")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.apache.install", "n")
		}
	}
}

query {
	id "webserverPort"
	required true
	dependencies advancedType
	label "Which port should the web server use"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes") && supplyOwnWebserver.equalsIgnoreCase("Yes")
	}
	validation {
		if (!webserverPort.isInteger()) {
			println "The value must be an integer"
			return false
		}
		if ((webserverPort.toInteger() < 1) || (webserverPort.toInteger() > 65535)) {
			println "The port number must be between 1 and 65536"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.apache.port", webserverPort)
	}
}

query {
	id "useHttps"
	required true
	dependencies advancedType
	label "Do you wish to use Secure HTTP as its default connection (instead of HTTP)"
	labelType "text"
	inputType "list"
	inputOptions "Yes, No"
	inputDefault "No"
	condition {
		advancedType.equalsIgnoreCase("Yes") && supplyOwnWebserver.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (useHttps.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.apache.https", "y")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.apache.https", "n")
		}
	}
}

query {
	id "memoryLimitPhp"
	required true
	dependencies advancedType
	label "Memory Limit for PHP"
	labelType "text"
	inputType "text"
	inputDefault "256"
	condition {
		advancedType.equalsIgnoreCase("Yes") && supplyOwnWebserver.equalsIgnoreCase("Yes")
	}
	validation {
		if (!memoryLimitPhp.isInteger()) {
			println "The value must be an integer"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.php.memory_limit", memoryLimitPhp)
	}
}

query {
	id "webserverDomainName"
	required true
	dependencies advancedType
	label "Fully qualified domain name of the web server"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes") && supplyOwnWebserver.equalsIgnoreCase("No")
	}
	validation {
		// Standard validation only
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.php.memory_limit", webserverDomainName)
	}
}

query {
	id "supplyOwnAppserver"
	required true
	dependencies advancedType
	label "Supply your own application server"
	labelType "text"
	inputType "list"
	inputOptions "Yes, No"
	inputDefault "No"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (supplyOwnAppserver.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.tomcat.install", "y")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.tomcat.install", "n")
		}
	}
}

query {
	id "httpPort"
	required true
	dependencies advancedType
	label "Which port should the application server use for HTTP"
	labelType "text"
	inputType "text"
	inputDefault "8080"
	condition {
		advancedType.equalsIgnoreCase("Yes") && supplyOwnAppserver.equalsIgnoreCase("Yes")
	}
	validation {
		if (!httpPort.isInteger()) {
			println "The value must be an integer"
			return false
		}
		if ((httpPort.toInteger() < 1) || (httpPort.toInteger() > 65535)) {
			println "The port number must be between 1 and 65536"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.tomcat.http_port", httpPort)
	}
}

query {
	id "sslPort"
	required true
	dependencies advancedType
	label "Which port should the application server use for SSL"
	labelType "text"
	inputType "text"
	inputDefault "8443"
	condition {
		advancedType.equalsIgnoreCase("Yes") && supplyOwnAppserver.equalsIgnoreCase("Yes")
	}
	validation {
		if (!sslPort.isInteger()) {
			println "The value must be an integer"
			return false
		}
		if ((sslPort.toInteger() < 1) || (sslPort.toInteger() > 65535)) {
			println "The port number must be between 1 and 65536"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.tomcat.ssl_port", sslPort)
	}
}

query {
	id "ajpPort"
	required true
	dependencies advancedType
	label "Which port should the application server use for AJP"
	labelType "text"
	inputType "text"
	inputDefault "8009"
	condition {
		advancedType.equalsIgnoreCase("Yes") && supplyOwnAppserver.equalsIgnoreCase("Yes")
	}
	validation {
		if (!ajpPort.isInteger()) {
			println "The value must be an integer"
			return false
		}
		if ((ajpPort.toInteger() < 1) || (ajpPort.toInteger() > 65535)) {
			println "The port number must be between 1 and 65536"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.tomcat.ajp_port", ajpPort)
	}
}

query {
	id "shutdownPort"
	required true
	dependencies advancedType
	label "Which port should the application server use for SHUTDOWN"
	labelType "text"
	inputType "text"
	inputDefault "8005"
	condition {
		advancedType.equalsIgnoreCase("Yes") && supplyOwnAppserver.equalsIgnoreCase("Yes")
	}
	validation {
		if (!shutdownPort.isInteger()) {
			println "The value must be an integer"
			return false
		}
		if ((shutdownPort.toInteger() < 1) || (shutdownPort.toInteger() > 65535)) {
			println "The port number must be between 1 and 65536"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.tomcat.shutdown.port", shutdownPort)
	}
}

query {
	id "redirectionUrl"
	required true
	dependencies advancedType
	label "Redirection URL"
	labelType "text"
	inputType "text"
	inputDefault "http://"
	condition {
		advancedType.equalsIgnoreCase("Yes") && supplyOwnAppserver.equalsIgnoreCase("No")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.services_url", redirectionUrl)
	}
}

query {
	id "pluginsDirectory"
	required true
	dependencies advancedType
	label "Specify the directory to install Build Forge services plugins to"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes") && supplyOwnAppserver.equalsIgnoreCase("No")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.services_plugin_path", pluginsDirectory)
	}
}

query {
	id "servicesDomainName"
	required true
	dependencies advancedType
	label "Fully qualified domain name of services server"
	labelType "text"
	inputType "text"
	inputDefault {
		InetAddress.getLocalHost().getCanonicalHostName()
	}
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.services_host", servicesDomainName)
	}
}

query {
	id "listenOnPort"
	required true
	dependencies advancedType
	label "Listen on port"
	labelType "text"
	inputType "text"
	inputDefault "3966"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		if (!listenOnPort.isInteger()) {
			println "The value must be an integer"
			return false
		}
		if ((listenOnPort.toInteger() < 1) || (listenOnPort.toInteger() > 65535)) {
			println "The port number must be between 1 and 65536"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.services_unsecure", listenOnPort)
	}
}

query {
	id "listenOnSecureport"
	required true
	dependencies advancedType
	label "Listen on secure port"
	labelType "text"
	inputType "text"
	inputDefault "49150"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		if (!listenOnSecureport.isInteger()) {
			println "The value must be an integer"
			return false
		}
		if ((listenOnSecureport.toInteger() < 1) || (shutdownPort.toInteger() > 65535)) {
			println "The port number must be between 1 and 65536"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.services_secure", listenOnSecureport)
	}
}

query {
	id "keystorePassword"
	required true
	dependencies advancedType
	label "Keystore password"
	labelType "text"
	inputType "password"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		// This value is only set if it is properly confirmed
		// com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.dbPass", keystorePassword)
	}
}

query {
	id "confirmKeystorePass"
	required true
	dependencies advancedType
	label "Confirm keystore password"
	labelType "text"
	inputType "password"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
		confirmKeystorePass.equals(keystorePassword)
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.keystore.password", confirmKeystorePass)
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.keystore.password.encrypted", "y")
	}
}

query {
	id "uploadCustomCert"
	required true
	dependencies advancedType
	label "Do you wish to modify default or upload a custom certificate"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes, No"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		if (uploadCustomCert.equalsIgnoreCase("No")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.secure", "n")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.secure", "y")
		}
		
	}
}

query {
	id "existingSignedCert"
	required true
	dependencies advancedType
	label "Do you have an existing secure certificate"
	labelType "text"
	inputType "list"
	inputDefault "No"
	inputOptions "Yes, No"
	condition {
		advancedType.equalsIgnoreCase("Yes") && uploadCustomCert.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		if (uploadCustomCert.equalsIgnoreCase("No")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.selfsigned", "n")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.selfsigned", "y")
		}
		
	}
}

query {
	id "validityPeriodType"
	required true
	dependencies advancedType
	label "Validity period unit"
	labelType "text"
	inputType "list"
	inputDefault "Years"
	inputOptions "Years, Months, Days"
	condition {
		advancedType.equalsIgnoreCase("Yes") && uploadCustomCert.equalsIgnoreCase("Yes") && existingSignedCert.equalsIgnoreCase("No")
	}
	validation {
	}
	action {
		if (validityPeriodType.equalsIgnoreCase("Years")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.selfsigned.duration.unit", "y")
		}
		else if (validityPeriodType.equalsIgnoreCase("Months")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.selfsigned.duration.unit", "m")
		}
		else if (validityPeriodType.equalsIgnoreCase("Days")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.selfsigned.duration.unit", "d")
		}
	}
}

query {
	id "validityPeriod"
	required true
	dependencies advancedType
	label "Validity period"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes") && uploadCustomCert.equalsIgnoreCase("Yes") && existingSignedCert.equalsIgnoreCase("No")
	}
	validation {
		if (!validityPeriod.isInteger()) {
			println "The value must be an integer"
			return false
		}
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.selfsigned.duration", validityPeriod)
	}
}

query {
	id "commonName"
	required true
	dependencies advancedType
	label "Common name for the certificate"
	labelType "text"
	inputType "text"
	inputDefault {
		InetAddress.getLocalHost().getCanonicalHostName()
	}
	condition {
		advancedType.equalsIgnoreCase("Yes") && uploadCustomCert.equalsIgnoreCase("Yes") && existingSignedCert.equalsIgnoreCase("No")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.selfsigned.company", commonName)
	}
}

query {
	id "locality"
	required true
	dependencies advancedType
	label "Locality"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes") && uploadCustomCert.equalsIgnoreCase("Yes") && existingSignedCert.equalsIgnoreCase("No")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.selfsigned.locality", locality)
	}
}

query {
	id "state"
	required true
	dependencies advancedType
	label "State or province"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes") && uploadCustomCert.equalsIgnoreCase("Yes") && existingSignedCert.equalsIgnoreCase("No")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.selfsigned.state.province", state)
	}
}

query {
	id "orgName"
	required true
	dependencies advancedType
	label "Organization name"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes") && uploadCustomCert.equalsIgnoreCase("Yes") && existingSignedCert.equalsIgnoreCase("No")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.selfsigned.state.province", state)
	}
}

query {
	id "orgUnit"
	required true
	dependencies advancedType
	label "Organization unit"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes") && uploadCustomCert.equalsIgnoreCase("Yes") && existingSignedCert.equalsIgnoreCase("No")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.selfsigned.state.province", orgUnit)
	}
}

query {
	id "countryName"
	required true
	dependencies advancedType
	label "Country/region name"
	labelType "text"
	inputType "list"
	inputDefault "United States"
	inputOptions "United States, Germany, Spain, France, Italy, Japan, Korea, Brazil, China, Taiwan"
	condition {
		advancedType.equalsIgnoreCase("Yes") && uploadCustomCert.equalsIgnoreCase("Yes") && existingSignedCert.equalsIgnoreCase("No")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.selfsigned.state.province", countryName)
	}
}

query {
	id "streetAddress"
	required true
	dependencies advancedType
	label "Street address"
	labelType "text"
	inputType "text"
	condition {
		advancedType.equalsIgnoreCase("Yes") && uploadCustomCert.equalsIgnoreCase("Yes") && existingSignedCert.equalsIgnoreCase("No")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.selfsigned.street.address", streetAddress)
	}
}

query {
	id "signedCertLocation"
	required true
	dependencies advancedType
	label "Please specify a signed certificate in a keystore of type pkcs12"
	labelType "text"
	inputType "text", "file"
	condition {
		advancedType.equalsIgnoreCase("Yes") && uploadCustomCert.equalsIgnoreCase("Yes") && existingSignedCert.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.ca.cert", signedCertLocation)
		signedCertLocation = null
	}
}

query {
	id "createShortcut"
	required true
	dependencies advancedType
	label "Create a shortcut on the desktop"
	labelType "text"
	inputType "list"
	inputDefault "Yes"
	inputOptions "Yes, No"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		if (createShortcut.equalsIgnoreCase("Yes")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.create_shortcut", "y")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.create_shortcut", "n")
		}
	}
}

query {
	id "startupOptions"
	required true
	dependencies advancedType
	label "Startup options"
	labelType "text"
	inputType "list"
	inputDefault "Start Build Forge in service mode"
	inputOptions "Start Build Forge in service mode, Do not start Build Forge"
	condition {
		advancedType.equalsIgnoreCase("Yes")
	}
	validation {
	}
	action {
		if (startupOptions.equalsIgnoreCase("Do not start Build Forge")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.console_startup", "nostart")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.console_startup", "start")
		}
	}
}

query {
	id "beta"
	required true
	dependencies advancedType
	label "BuildForge Beta"
	labelType "text"
	inputType "none"
	condition {
		// This will never be shown
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.beta", "n")
	}
}

query {
	id "installType"
	required true
	dependencies features
	label "BuildForge install type"
	labelType "text"
	inputType "none"
	inputDefault {
		
	}
	condition {
		// This will never be shown
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.install_type", installType)
	}
}

query {
	id "win2k8"
	required true
	dependencies features
	label "BuildForge is Win2k8"
	labelType "text"
	inputType "none"
	inputDefault "n"
	condition {
		// This will never be shown
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		if (System.getProperty("os.name").equalsIgnoreCase("Windows 2008")) {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.win2k8", "y")
		}
		else {
			com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.win2k8", "n")
		}
	}
}

query {
	id "bfPlatform"
	required true
	dependencies features
	label "BuildForge platform"
	labelType "text"
	inputType "none", "file"
	inputDefault {
		platform
	}
	condition {
		// This will never be shown
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setPlatformProperty(pkg, env, platform, "user.buildforge.platform", bfPlatform)
		bfPlatform = null
	}
}

query {
	id "javaHome"
	required true
	dependencies features
	label "BuildForge java home"
	labelType "text"
	inputType "none"
	inputDefault {
		System.getProperty("java.home")
	}
	condition {
		// This will never be shown
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		def home = System.getProperty("java.home")
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.java.home", home)
	}
}

query {
	id "runAs"
	required true
	dependencies features
	label "BuildForge run as"
	labelType "text"
	inputType "none"
	inputDefault {
		""
	}
	condition {
		// This will never be shown
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.run_as", home)
	}
}

query {
	id "fileStorage"
	required true
	dependencies platform
	label "BuildForge run as"
	labelType "text"
	inputType "none", "file"
	inputDefault {
	}
	condition {
		// This will never be shown
	}
	validation {
    	(fileStorage && fileStorage.trim().length() > 0 && ((!fileStorage.contains("\$") && fileStorage.trim().length() < com.ibm.edp.rfe.model.ModelUtil.getMaxfileStorageLength(packageId, version, platform)) || fileStorage.contains("\$")))
	}
	action {
		def installLoc = com.ibm.edp.rfe.model.ModelUtil.getPlatformProperty(packageId, version, platform, "installLocation")
		if (platform.equalsIgnoreCase("win32") || platform.equalsIgnoreCase("win32.vista")) {
			installLoc = installLoc + "\\temp"
		}
		else {
			installLoc = installLoc + "/temp"
		}
		com.ibm.edp.rfe.model.ModelUtil.setPlatformProperty(pkg, env, platform, "user.buildforge.file_storage", installLoc)
		fileStorage = null
	}
}

query {
	id "uninstallFull"
	required true
	dependencies features
	label "BuildForge uninstallFull"
	labelType "text"
	inputType "none"
	inputDefault {
		"com.ibm.buildforge.console.CoreWrapper_" + version
	}
	condition {
		// This will never be shown
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.uninstallFull_" + version, uninstallFull)
	}
}

query {
	id "realHost"
	required true
	dependencies features
	label "BuildForge real host"
	labelType "text"
	inputType "none"
	inputDefault {
		InetAddress.getLocalHost().getCanonicalHostName() + ":81"
	}
	condition {
		// This will never be shown
	}
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
		com.ibm.edp.rfe.model.ModelUtil.setUserData(pkg, "user.buildforge.real_host", realHost)
	}
}
