/*
 *+------------------------------------------------------------------------+
 *| Licensed Materials - Property of IBM                                   |
 *| (C) Copyright IBM Corp. 2012.  All Rights Reserved.              |
 *|                                                                        |
 *| US Government Users Restricted Rights - Use, duplication or disclosure |
 *| restricted by GSA ADP Schedule Contract with IBM Corp.                 |
 *+------------------------------------------------------------------------+
 */
query_script_version '1.0.0'

query_order {
	general {
		install {
		    packageId
			version
			customizations
			defaultProfile
			platform
			advancedType
			installLocation
			sharedLocation
			languages
			features
		}
		uninstall {
			packageId
			version
			customizations
			defaultProfile
			platform
			installLocation
		}
		update {
			packageId
			version
			customizations
			defaultProfile
			platform
			advancedType
			installLocation
			sharedLocation
			languages
			features
		}
		credentials {
			uid
			pwd
		}
	}
}

query {
    id "packageId"
    required true
    label "Enter Product Name"
    labelType "text"   // can be radio or checkbox
    inputType "map"
    inputOptions { 
       com.ibm.edp.rfe.model.ModelUtil.getPackageNames()
    }
    condition {
        
    }
    validation {
    	//the value is automatically validated against inputOptions
    }
    action {
    	pkg.getIdentity().setId( packageId )
    }
}

query {
    id "version"
    dependencies packageId
    required true
    label "Enter version"
    labelType "text"   // can be radio or checkbox
    inputType "list"
    inputDefault { 
    	com.ibm.edp.rfe.model.ModelUtil.getLatestVersion( packageId )    	     
    }
    inputOptions {
        com.ibm.edp.rfe.model.ModelUtil.getAllVersions( packageId )
    }   
    condition {
        
    }
    validation {
    	//the value is automatically validated against inputOptions
    }
    action {
    	if(cmd.getName() != "uninstall") pkg.getIdentity().setVersion( version )
    }
}

query {
    id "customizations"
    dependencies packageId, version
    required true
    inputType "none"
    action {
    	com.ibm.edp.rfe.console.query.QueryRuntime.getInstance().getCustomQuery(packageId, version)
    }
}

query {
    id "platform"
    required true
    dependencies packageId, version
    label "Select platform"
    labelType "text"   // can be radio or checkbox
    inputType "map", "multiple"   
    inputDefault "All"
    inputOptions {
        com.ibm.edp.rfe.model.ModelUtil.getPlatforms( packageId, version ) //have a map,
    } 
    condition {
       
    }
    validation {
    	//the value is automatically validated against inputOptions
    }
    action {
    	//if all is set platform value to all platforms
    	if("all" == platform) {
			platform = com.ibm.edp.rfe.model.ModelUtil.getPlatforms( packageId, version ).values().findAll{ it != "all"}
		} else {
		    platform = platform.split( com.ibm.edp.rfe.model.ModelUtil.VALUE_DELIMETER ).collect{it}		
		}
    }
}

query {
	id "defaultProfile"
	dependencies packageId, version
	required true
	inputType "none"
	action {		
		com.ibm.edp.rfe.model.ModelUtil.setDefaultProfile(pkg, env)
	}
}

query {
    id "advancedType"
    required true
    dependencies platform
    label "Do you want to enter advanced mode?"
    labelType "text"   // can be radio or checkbox
    inputType "list"  
    inputDefault "No"
    inputOptions "Yes, No"  
    inputIgnoreCase true
    condition {
        
    }  
    validation {
    	//the value is automatically validated against inputOptions
    }
    action {        	
    }
}

query {
    id "installLocation"
    required true
    dependencies platform
    label {
        "Enter the ${platform?platform+' ':''}install location"
    }    
    labelType "text"
    inputType "text", "file"
    inputDefault {        
    	com.ibm.edp.rfe.model.ModelUtil.getDefaultInstallLocation( packageId, version, platform )
    }
    condition {
		cmd.getName().equalsIgnoreCase("uninstall") || advancedType.equalsIgnoreCase("Yes")
    }
    validation {
    	(installLocation && installLocation.trim().length() > 0 && ((!installLocation.contains("\$") && installLocation.trim().length() < com.ibm.edp.rfe.model.ModelUtil.getMaxInstallLocationLength(packageId, version, platform)) || installLocation.contains("\$")))
    }
    action {
        com.ibm.edp.rfe.model.ModelUtil.setInstallLocation(pkg, env, platform, installLocation)
        installLocation = null
    }
}

query {
    id "sharedLocation"
    required true
    dependencies platform
    label {
    	"Enter the ${platform?platform + ' ':''}shared location"
    }
    labelType "text"
    inputType "text", "file"
    inputDefault { 
       com.ibm.edp.rfe.model.ModelUtil.getDefaultSharedLocation( packageId, version, platform )
    }
    condition {
        advancedType.equalsIgnoreCase("Yes")
    }
    validation {
    	(sharedLocation && sharedLocation.trim().length() > 0 && ((!sharedLocation.contains("\$") && sharedLocation.trim().length() < com.ibm.edp.rfe.model.ModelUtil.getMaxInstallCommonLocationLength(packageId, version, platform)) || sharedLocation.contains("\$")))
    }
    action {
    	com.ibm.edp.rfe.model.ModelUtil.setSharedLocation(pkg, env, platform, sharedLocation)
    	sharedLocation = null
    }
}

query {
    id "languages"
    required false
    dependencies advancedType
    label "Select the languages to install"
    labelType "text"
    inputType "map", "multiple"
    inputDefault "Default"
    inputOptions {
        com.ibm.edp.rfe.model.ModelUtil.getLanguages( packageId, version )
    }
    condition {
        advancedType.equalsIgnoreCase("Yes")
    }  
    validation {
    	//the value is automatically validated against inputOptions
    }
    action {
    	com.ibm.edp.rfe.model.ModelUtil.setLanguages(pkg, languages)
    }
}

query {
    id "features"
    required false
    dependencies advancedType
    label "Select the features to install"
    labelType "text"
    inputType "map", "multiple"
    inputDefault "Default"
    inputOptions { 
    	com.ibm.edp.rfe.model.ModelUtil.getFeatures( packageId, version )
    }
    condition {
        advancedType.equalsIgnoreCase("Yes")
    }
    validation {
    	//the value is automatically validated against inputOptions
    }
    action {
    	com.ibm.edp.rfe.model.ModelUtil.setFeatures(pkg, features)
    }
}

query {
	id "uid"
	required true
	label "Enter user"
	labelType "text"
	inputType "text"
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
	}
}

query {
	id "pwd"
	required false
	dependencies uid
	label "Enter password"
	labelType "text"
	inputType "password"
	inputDefault ""
	validation {
		//the value is automatically validated against inputOptions
	}
	action {
	}
}